@@ -62,7 +62,7 @@ def subcommand(*subparser_args, parent=subparsers, alias='', name=None):
 		return func
 	return decorator
 
-@subcommand(arg('-t','--default_tags', nargs='+'), alias='a')
+@subcommand(arg('-t','--default_tags', nargs='+', default=[]), alias='a')
 def add(args): 
 	ansi.hide_cursor()
 	print(*[f'{key}\t{generator}' for key, generator in GENERATORS_DICT.items()],sep='\n')
@@ -175,7 +175,7 @@ CMD_DICT = {'r': review, 'R': review,
 	    'x': delete, 'X': delete,
 	    'e': edit, 'E': edit_metadata,
 	    't': edit_tags, 'T': edit_tags}
-@subcommand(CARDS, alias='b')
+@subcommand(CARDS, arg('-t','--default_tags', nargs='+', default=[]), alias='b')
 def browse(args, reviewing = False):
 	args.scrollback = True
 	cards = args.cards
@@ -192,10 +192,12 @@ def browse(args, reviewing = False):
 		ansi.line_wrap_off()
 
 		for i, card in enumerate(cards):
-			if card.deleted:
-				ansi.crossout()
 			if card.due_as_of(args.review_date):
 				ansi.bold()
+				ansi.blue()
+			if card.deleted:
+				ansi.crossout()
+				ansi.red()
 			if i==sel:
 				ansi.highlight()
 			print(card)
@@ -278,10 +280,16 @@ def display_filter(args):
 		if args.id_only:
 			print(card.id)
 			continue
-		if card.deleted():
-			ansi.crossout()
+		if COLORIZE:
+			if card.due_as_of(TODAY):
+				ansi.bold()
+				ansi.blue()
+			if card.deleted:
+				ansi.crossout()
+				ansi.red()
 		print(card.id, card, sep='\t')
-		ansi.reset()
+		if COLORIZE:
+			ansi.reset()
 	
 @subcommand()
 def purge(args):
@@ -311,14 +319,10 @@ for alias, generator in GENERATORS_DICT.items():
 	p.set_defaults(func = generate, generator = generator)
 
 # parse the command line arguments
-parser.set_defaults(cards = [], func = None, review_date = TODAY, scrollback = False, card = None)
+parser.set_defaults(cards = [], func = lambda args: parser.print_help(), review_date = TODAY, scrollback = False, card = None)
 parser._action_groups[0].title = 'commands'
 parser._action_groups.pop()
 args = parser.parse_args()
-if not args.func:
-	args.func = statistics
-	args.card = None
-	args.cards = ALL_CARDS
 # accept a file of newline separated card ids
 if not sys.stdin.isatty():
 	ids = [int(line.strip().split()[0]) for line in sys.stdin]
